@@ -63,13 +63,15 @@ class _tpl_attribute_flag(_tpl_attribute):
 
 
 class _tpl_attribute_function(_tpl_attribute):
-  def __init__(self, token: str, value=None):
+  def __init__(self, token: str, value=None, suppress_semicolon=False):
     super().__init__(token)
     self.set_value(value)
+    self.suppress_semicolon = suppress_semicolon
 
   def __str__(self):
     v = self.get_value()
     if v is None:
       return super().__str__()
     else:
-      return f"\\{self._token}{{{str(v)}}};"
+      semicolon = "" if self.suppress_semicolon else ";"
+      return f"\\{self._token}{{{str(v)}}}" + semicolon
