@@ -33,7 +33,10 @@ class _tpl_curve_data:
     if sortdata:
       self.x, self.y, self.xerror, self.yerror = self.__class__.__sort(self.x, self.y, self.xerror, self.yerror)
 
-    self.label = _tpl_attribute_function(token="addlegendentry", value=label)
+    self.label = _tpl_attribute_function(
+        token="addlegendentry", value=label,
+        suppress_semicolon=True
+    )
     self.tablename = "table%d" % self.__class__.__counter
     self.__class__.__counter += 1
     self.color = _tpl_attribute_variable(token="color", value=color)
