@@ -113,6 +113,24 @@ class figure:
   def set_scaled_y_ticks(self, scaled_ticks: bool = True):
     self.__yticklabel._set_scaled(scaled_ticks)
 
+  def set_x_ticks(self, data: list[float] = None):
+    self.__xticklabel._set_ticks(data)
+
+  def set_y_ticks(self, data: list[float] = None):
+    self.__yticklabel._set_ticks(data)
+
+  def set_x_ticks_from_data(self, use_data: bool = True):
+    self.__xticklabel._set_ticks_use_data(use_data)
+
+  def set_y_ticks_from_data(self, use_data: bool = True):
+    self.__yticklabel._set_ticks_use_data(use_data)
+
+  def set_x_tick_labels(self, labels: list[str] = None):
+    self.__xticklabel._set_tick_labels(labels)
+
+  def set_y_tick_labels(self, labels: list[str] = None):
+    self.__yticklabel._set_tick_labels(labels)
+
   def set_legend_position(self, pos: str):
     self.__legend.pos.set_value(pos)
 
